// File    : MSGTST.H
// Author  : Eric Woodruff,  CIS ID: 72134,1150
// Updated : Wed 08/02/95 14:37:14
// Note    : Copyright 1993-95, Eric Woodruff, All rights reserved
// Compiler: Borland C++ 3.1 to 4.xx
//
// This is the test program header file.
//

// ****************************************************************************
// Message/input box demo stuff

#define TEXT_SIZE       101
#define TEST_STR_SIZE    46
#define HISTORY_ID       12     // This is shared between the dynamic and
                                // resource file input boxes.

// These are data structures for the demo and test program.
struct TextRecord
{
    char Lines[16][TEXT_SIZE];
    char Buttons[15][TEXT_SIZE];
    char TxtTitle[TEXT_SIZE];
    char Validator[TEXT_SIZE];
};

struct ParamRecord
{
    ushort LineCount;
    ushort ButtonCount;
    ushort Options;
    ushort Color;
    char   LineLen[3];
    char   MaxTime[5];
    char   BeepTime[5];
    char   Pitch[5];
};

// Test function to put the functions through their paces.
TDialog *makeMIBXTestDialog(void);

// ****************************************************************************
// Thermometer bar demo stuff

// Data structure for the test dialog.
struct ThermoRecord
{
    ushort backGrnd;
    ushort foreGrnd;
    ushort Options;
    char   TitleText[256];
    char   MessageText[256];
    char   ThermWidth[3];
    char   Iterations[9];
    char   Delay[4];
};

// Streamed dialog box data structure.
struct StreamDataRec
{
    char FSpec[256];
    ThermoDataRec DemoData;
};

// Demonstration function prototypes.
TDialog *makeThermoTestDialog(void);

void DemoProcess(void *Owner, void *thBar);
void FileSearch(void *Owner, void *thBar);

// ****************************************************************************
// General demo stuff

// Exit code values.
#define EXIT_NOERR      0
#define EXIT_RSCERR     1001
#define EXIT_SYNTAX     1002
#define EXIT_SWERR      1003

const int
    cmAbout         = 100,      // Standard event values.
    cmRepaint       = 101,
    cmColors        = 102,
    cmChangePalettes = 103,
    cmLoadCfg       = 104,
    cmSaveCfg       = 105,
    cmScreenSize    = 106,
    cmUserScreen    = 107,

#if _TV_VERSION == 0x0103
    cmDosShell      = 111,      // Already defined in TV 2.0
    cmCloseAll      = 112,
#endif

    cmTestMsgBox    = 114,      // Other command values.
    cmChgText       = 115,
    cmFormatTest    = 116,
    cmButtonMenu    = 117,
    cmQuitMenu      = 118,
    cmTestInpBox    = 119,
    cmStrmMsgBox    = 120,
    cmStrmInpBox    = 121,
    cmExpWinDemo    = 122,
    cmExpWinRscDemo = 123,
    cmBarDemo1      = 124,
    cmBarDemo2      = 125,
    cmBarDemo3      = 126,
    cmBarDemo4      = 127;

// ***************************************************************************

#if defined(INCLUDE_HEAPVIEW)
class _FAR THeapView;
#endif

class TDemoApp : public TApplication
{
#if defined(INCLUDE_HEAPVIEW)
private:
    THeapView *heap;
#endif

public:
    TDemoApp();
    static TMenuBar *initMenuBar( TRect r );
    static TStatusLine *initStatusLine( TRect r );
    static TDeskTop *initDeskTop(TRect r);

    virtual void initScreen();                  // Sets correct palette.
    virtual void idle(void);
    virtual void getEvent(TEvent& event);
    virtual void handleEvent(TEvent& Event);
    virtual void outOfMemory(void);
    virtual TPalette& getPalette() const;

    void loadConfig(Boolean UseFileSetting);
    void saveConfig(void);

private:
    void FormatTest(void);

    void ExpWinDemo(void);

    void BarDemo1(void);
    void BarDemo2(void);
    void BarDemo3(void);
    void BarDemo4(void);
};

#if _TV_VERSION == 0x0103
// A couple of useful functions.
ushort executeDialog(TDialog *d, void *data);
#endif

Boolean isTileable(TView *p, void *);

// ****************************************************************************
// Here's a simple derived class for the demonstration.

// An addition to the TThermometer Bar options.  This is strictly for the
// demo and is masked off before the options are given to the thermometer bar.
#define DoPause  0x0020

class TMyThermometer : public TThermometer
{
public:
    Boolean  pauseHalfway;
    short    Delay;

    TMyThermometer(const TRect &r, thermProcess thFunc = NULL,
      ulong TotIts = 0L, ushort Opts = (thIsBoxed | thDoExit),
      uchar backGrnd = pbfLightXHatch, uchar foreGrnd = pbfSolid,
      ushort ActCmd = cmOK) :
        TThermometer(r, thFunc, TotIts, Opts, backGrnd, foreGrnd, ActCmd) {};

    inline void setPause(Boolean pause)   // Set pause on or off.
        { pauseHalfway = pause; }

    inline void setDelay(short time)    // Set interation delay.
        { Delay = time; }
};
